pitchtools.diatonic_pitch_class_name_to_diatonic_pitch_class_number
===================================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_class_name_to_diatonic_pitch_class_number
